Module angle_reference

Module angle_reference 

Shared output-angle reference conventions for power-flow solutions.

Enums

AngleReference
Reference angle convention for reported bus voltage angles.
DistributedAngleWeight
Weighting scheme for AngleReference::Distributed.

Functions

apply_angle_reference
Apply an output angle reference convention to all buses in the network.
apply_angle_reference_subset
Apply an output angle reference convention to one island/subset of buses.