pub enum DistributedAngleWeight {
LoadWeighted,
GenerationWeighted,
InertiaWeighted,
}Expand description
Weighting scheme for AngleReference::Distributed.
Variants
LoadWeighted
Weight each bus by its total active load (MW).
GenerationWeighted
Weight each bus by its total online generation (MW).
InertiaWeighted
Weight each bus by connected generator inertia (H * MBASE).