pub struct OperationalLimits {
pub limit_sets: HashMap<String, OperationalLimitSet>,
}Expand description
Container for all operational limits on the Network.
Fields
limit_sets: HashMap<String, OperationalLimitSet>All limit sets, keyed by CIM mRID.
Implementations
Sourceimpl OperationalLimits
impl OperationalLimits
Sourcepub fn total_limit_count(&self) -> usize
pub fn total_limit_count(&self) -> usize
Total number of individual limit values across all sets.
Sourcepub fn sets_for_equipment<'a>(
&'a self,
equipment_mrid: &'a str,
) -> impl Iterator<Item = &'a OperationalLimitSet>
pub fn sets_for_equipment<'a>( &'a self, equipment_mrid: &'a str, ) -> impl Iterator<Item = &'a OperationalLimitSet>
Iterate all limit sets attached to a given equipment mRID.
Sourcepub fn sets_for_bus(
&self,
bus: u32,
) -> impl Iterator<Item = &OperationalLimitSet>
pub fn sets_for_bus( &self, bus: u32, ) -> impl Iterator<Item = &OperationalLimitSet>
Iterate all limit sets attached to a given bus number.