pub struct ScrxParams {
pub tr: f64,
pub k: f64,
pub te: f64,
pub emin: f64,
pub emax: f64,
pub rcrfd: Option<f64>,
}Expand description
Simplified Bus-Fed Static Exciter (PSS/E SCRX).
This is a standard planning-level model for static exciters when detailed parameters are unavailable. For precise transient stability studies, upgrade to ESST4B or ESST3A when static exciter field test data is available. See the module-level documentation for the full model mapping.
PSS/E params: TR K TE EMIN EMAX [Rcrfd]
Fields
tr: f64Transducer time constant (s).
k: f64Exciter gain.
te: f64Exciter time constant (s).
emin: f64Minimum field voltage (pu).
emax: f64Maximum field voltage (pu).
rcrfd: Option<f64>Ratio of exciter to field current (optional).